package org.jtheque.films.controllers.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.view.able.controller.Controller;
import org.jtheque.films.view.able.IActorView;
import org.jtheque.films.view.impl.models.ActorsModel;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.primary.controller.able.ControllerState;

import javax.swing.event.TreeSelectionListener;

import java.util.List;

/**
 * An actor controller specification.
 *
 * @author Baptiste Wicht
 */
public interface IActorController extends Controller, TreeSelectionListener {
    /**
     * Save the current actor.
     */
    void save();

    /**
     * Edit the current actor.
     */
    void manualEdit();

    /**
     * Create a new actor.
     */
    void createActor();

    /**
     * Delete the current actor.
     */
    void deleteCurrentActor();

    /**
     * Cancel the current state.
     */
    void cancel();

    /**
     * Return the model of the view.
     *
     * @return The model of the view.
     */
    ActorsModel getViewModel();

    @Override
    IActorView getView();

    /**
     * Return the state "view".
     *
     * @return The state "view";
     */
    ControllerState getViewState();

    /**
     * Return the state "auto add".
     *
     * @return The state "auto add";
     */
    ControllerState getAutoAddState();

    /**
     * Return the state "new".
     *
     * @return The state "new";
     */
    ControllerState getNewObjectState();

    /**
     * Return the state "edit".
     *
     * @return The state "edit";
     */
    ControllerState getModifyState();

    String getDataType();

    List<ActorImpl> getDisplayList();
}
