package org.jtheque.films.controllers.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.view.able.controller.Controller;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.view.able.IFilmView;
import org.jtheque.films.view.impl.models.FilmsModel;
import org.jtheque.primary.controller.able.ControllerState;

import javax.swing.event.TreeSelectionListener;
import java.awt.event.MouseListener;
import java.util.List;

/**
 * A film controller specification.
 *
 * @author Baptiste Wicht
 */
public interface IFilmController extends Controller, MouseListener, TreeSelectionListener {
    /**
     * Save the current film.
     */
    void save();

    /**
     * Display a film in the interface.
     *
     * @param film The film to edit.
     */
    void view(FilmImpl film);

    /**
     * Edit manually a film.
     */
    void manualEdit();

    /**
     * Create a new film.
     */
    void createFilm();

    /**
     * Delete the current film.
     */
    void deleteCurrentFilm();

    /**
     * Cancel the current state.
     */
    void cancel();

    /**
     * Send the current film by email.
     */
    void sendCurrentFilmByMail();

    /**
     * Print the current film.
     */
    void printCurrentFilm();

    /**
     * Return the model of the view.
     *
     * @return The model of the view.
     */
    FilmsModel getViewModel();

    @Override
    IFilmView getView();

    /**
     * Return the state "view".
     *
     * @return The state "view";
     */
    ControllerState getViewState();

    /**
     * Return the state "auto add".
     *
     * @return The state "auto add";
     */
    ControllerState getAutoAddState();

    /**
     * Return the state "new".
     *
     * @return The state "new";
     */
    ControllerState getNewObjectState();

    /**
     * Return the state "edit".
     *
     * @return The state "edit";
     */
    ControllerState getModifyState();
    
    List<FilmImpl> getDisplayList();

    String getDataType();
}
