package org.jtheque.films.controllers.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.films.controllers.able.IExportController;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.impl.utils.file.exports.Exporter;
import org.jtheque.films.services.impl.utils.file.exports.ExporterFactory;
import org.jtheque.films.services.impl.utils.file.jt.FileFilterFactory;
import org.jtheque.films.services.impl.utils.search.FilmSearch;
import org.jtheque.films.services.impl.utils.search.Search;
import org.jtheque.films.utils.Constants.Files.FileType;
import org.jtheque.films.view.able.IExportView;
import org.jtheque.core.managers.view.able.controller.AbstractController;

import javax.annotation.Resource;

/**
 * A controller for the export view.
 *
 * @author Baptiste Wicht
 */
public final class ExportController extends AbstractController implements IExportController {
    private FileType fileType;

    @Resource
    private IExportView exportView;

    @Override
    public void openExportView(FileType fileType) {
        this.fileType = fileType;

        exportView.sendMessage("filter", FileFilterFactory.getFileFilter(fileType));
        displayView();
    }

    @Override
    public void export(FilmSearch search, String filePath) {
        Exporter exporter = ExporterFactory.getExporter(fileType);
        
        search.setResults(search.getSearcher().search(search));
        exporter.setSearch(search);

        exporter.export(filePath);
    }

    @Override
    public void exportFilm(String filePath, FilmImpl film) {
        Exporter exporter = ExporterFactory.getExporter(FileType.JTF);

        Search<FilmImpl> search = new FilmSearch();
        search.setResult(film);
        exporter.setSearch(search);

        exporter.export(filePath);
    }

    @Override
    public IExportView getView() {
        return exportView;
    }
}