package org.jtheque.films.controllers.impl.state.actor;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.undo.IUndoRedoManager;
import org.jtheque.films.controllers.able.IActorController;
import org.jtheque.films.controllers.impl.undo.delete.DeletedActorEdit;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.view.impl.models.ActorsModel;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.view.able.ViewMode;

import javax.annotation.Resource;

/**
 * A actor controller state for the state "view".
 *
 * @author Baptiste Wicht
 */
public final class ViewActorState implements ControllerState {
    @Resource
    private IActorController controller;

    @Resource
    private IActorService actorService;
    
    @Override
    public ActorsModel getViewModel() {
        return controller.getViewModel();
    }

    @Override
    public void apply() {
        controller.getView().setEnabled(false);
        controller.getView().getToolbarView().setDisplayMode(ViewMode.VIEW);

        if (getViewModel().getCurrentActor() != null) {
            controller.getView().select(getViewModel().getCurrentActor());
        }
    }

    @Override
    public ControllerState save(FormBean infos) {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState cancel() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState create() {
        return controller.getNewObjectState();
    }

    @Override
    public ControllerState manualEdit() {
        return controller.getModifyState();
    }

    @Override
    public ControllerState delete() {
        boolean deleted = actorService.delete(getViewModel().getCurrentActor());

        if (deleted) {
            Managers.getManager(IUndoRedoManager.class).addEdit(new DeletedActorEdit(getViewModel().getCurrentActor()));

            controller.getView().selectFirst();
        }

        return null;
    }

    @Override
    public ControllerState autoEdit(Data data) {
        ActorImpl actor = (ActorImpl) data;

        getViewModel().setCurrentActor(actor);

        return controller.getAutoAddState();
    }

    @Override
    public ControllerState view(Data data) {
        ActorImpl actor = (ActorImpl) data;

        getViewModel().setCurrentActor(actor);

        return null;
    }
}