package org.jtheque.films.controllers.impl.state.realizer;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.core.managers.undo.IUndoRedoManager;
import org.jtheque.films.controllers.able.IRealizerController;
import org.jtheque.films.controllers.impl.undo.create.CreatedRealizerEdit;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.films.view.impl.fb.RealizerFormBean;
import org.jtheque.films.view.impl.models.RealizersModel;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.view.able.ViewMode;

import javax.annotation.Resource;

/**
 * A realizer controller state for the state "new".
 *
 * @author Baptiste Wicht
 */
public final class NewRealizerState implements ControllerState {
    @Resource
    private IRealizerController controller;

    @Resource
    private IRealizersService realizersService;
    
    @Override
    public RealizersModel getViewModel() {
        return controller.getViewModel();
    }

    @Override
    public void apply() {
        getViewModel().setCurrentRealizer(realizersService.getEmptyRealizer());
        controller.getView().setEnabled(true);
        controller.getView().getToolbarView().setDisplayMode(ViewMode.NEW);
    }

    @Override
    public ControllerState save(FormBean bean) {
        RealizerFormBean infos = (RealizerFormBean) bean;

        RealizerImpl realizer = new RealizerImpl();

        realizer.setName(infos.getName());
        realizer.setFirstName(infos.getFirstName());
        realizer.setNote(infos.getNote());
        realizer.setTheCountry(infos.getCountry());

        realizersService.create(realizer);

        Managers.getManager(IUndoRedoManager.class).addEdit(new CreatedRealizerEdit(realizer));

        controller.getView().resort();

        return controller.getViewState();
    }

    @Override
    public ControllerState cancel() {
        ControllerState nextState = null;

        controller.getView().selectFirst();

        if (realizersService.getRealizers().size() <= 0) {
            nextState = controller.getViewState();
        }

        return nextState;
    }

    @Override
    public ControllerState create() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState manualEdit() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState delete() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState autoEdit(Data data) {
        RealizerImpl realizer = (RealizerImpl) data;

        if (Managers.getManager(IViewManager.class).askI18nUserForConfirmation(
                "realizer.dialogs.confirmSave", "realizer.dialogs.confirmSave.title")) {
            controller.save();
        }

        getViewModel().setCurrentRealizer(realizer);

        return controller.getAutoAddState();
    }

    @Override
    public ControllerState view(Data data) {
        RealizerImpl realizer = (RealizerImpl) data;

        if (Managers.getManager(IViewManager.class).askI18nUserForConfirmation(
                "realizer.dialogs.confirmSave", "realizer.dialogs.confirmSave.title")) {
            controller.save();
        }

        getViewModel().setCurrentRealizer(realizer);

        return controller.getViewState();
    }
}