package org.jtheque.films.controllers.impl.undo.delete;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.primary.od.BorrowerImpl;
import org.jtheque.primary.services.able.IBorrowersService;

import javax.annotation.Resource;
import javax.swing.undo.AbstractUndoableEdit;
import javax.swing.undo.CannotRedoException;
import javax.swing.undo.CannotUndoException;

/**
 * An edit for a deletion of borrower.
 *
 * @author Baptiste Wicht
 */
public final class DeletedBorrowerEdit extends AbstractUndoableEdit {
    private static final long serialVersionUID = -3037357344759861059L;

    private final BorrowerImpl borrower;

    @Resource
    private IBorrowersService borrowersService;

    /**
     * Construct a new DeletedKindEdit.
     *
     * @param borrower The deleted kind.
     */
    public DeletedBorrowerEdit(BorrowerImpl borrower) {
        super();

        Managers.getManager(IBeansManager.class).inject(this);

        this.borrower = borrower;
    }

    @Override
    public void undo() throws CannotUndoException {
        super.undo();

        borrowersService.create(borrower);
    }

    @Override
    public void redo() throws CannotRedoException {
        super.redo();

        borrowersService.delete(borrower);
    }

    @Override
    public String getPresentationName() {
        return Managers.getManager(ILanguageManager.class).getMessage("undo.edits.delete");
    }
}