package org.jtheque.films.persistence;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.films.controllers.able.IActorController;
import org.jtheque.films.controllers.able.IFilmController;
import org.jtheque.films.controllers.able.IRealizerController;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.primary.od.abstraction.Data;

import javax.annotation.Resource;

import java.util.Collections;
import java.util.List;

/**
 * This class give a data access to the sorters. It simplifies the access to the data without know the exact type
 * of data.
 *
 * @author Baptiste Wicht
 */
public final class DataProvider {
    private final String content;

    @Resource
    private IFilmController filmController;

    @Resource
    private IActorController actorController;

    @Resource
    private IRealizerController realizerController;
    
    /**
     * Construct a new <code>SorterDataProvider</code> with a specific type of content.
     *
     * @param content The content to search
     */
    public DataProvider(String content) {
        super();

        Managers.getManager(IBeansManager.class).inject(this);

        this.content = content;
    }

    /**
     * Return all the data of the specified type.
     *
     * @return A collection of <code>Data</code>
     */
    public List<? extends Data> getDatas() {
        final List<? extends Data> datas;

        if (IFilmsService.DATA_TYPE.equals(content)) {
            datas = filmController.getViewModel().getDisplayList();
        } else if (IActorService.DATA_TYPE.equals(content)) {
            datas = actorController.getViewModel().getDisplayList();
        } else if (IRealizersService.DATA_TYPE.equals(content)) {
            datas = realizerController.getViewModel().getDisplayList();
        } else {
            datas = Collections.<Data>emptyList();
        }

        return datas;
    }
}