package org.jtheque.films.persistence.od;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.resource.IResourceManager;
import org.jtheque.core.managers.resource.ImageType;
import org.jtheque.core.managers.properties.IPropertiesManager;
import org.jtheque.films.persistence.od.abstraction.Actor;
import org.jtheque.films.persistence.od.temp.PersonTemporaryContext;
import org.jtheque.films.utils.Constants;

import javax.swing.Icon;

/**
 * Cette classe reprsente un acteur et toutes ses donnes.
 *
 * @author Baptiste Wicht
 */
public final class ActorImpl extends Actor {
    private ActorImpl memento;
    private boolean mementoState;

    private final PersonTemporaryContext temporaryContext;

    /**
     * Construct a new ActorImpl.
     */
    public ActorImpl() {
        super();

        temporaryContext = new PersonTemporaryContext();
    }

    @Override
    public PersonTemporaryContext getTemporaryContext() {
        return temporaryContext;
    }

    @Override
    public String getAffichableText() {
        return getFirstName() + ' ' + getName();
    }

    @Override
    public String toString() {
        return getAffichableText();
    }

    @Override
    public int hashCode() {
        return Managers.getManager(IPropertiesManager.class).hashCode(this);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if (obj == null) {
            return false;
        }

        if (getClass() != obj.getClass()) {
            return false;
        }

        final Actor other = (Actor) obj;

        if (getName() == null) {
            if (other.getName() != null) {
                return false;
            }
        } else if (!getName().equals(other.getName())) {
            return false;
        }

        if (getNote() == null) {
            if (other.getNote() != null) {
                return false;
            }
        } else if (!getNote().equals(other.getNote())) {
            return false;
        }

        if (getTheCountry() == null) {
            if (other.getTheCountry() != null) {
                return false;
            }
        } else if (!getTheCountry().equals(other.getTheCountry())) {
            return false;
        }

        if (getFirstName() == null) {
            if (other.getFirstName() != null) {
                return false;
            }
        } else if (!getFirstName().equals(other.getFirstName())) {
            return false;
        }

        return true;
    }

    @Override
    public Icon getIcon() {
        return Managers.getManager(IResourceManager.class).getIcon(Constants.IMAGE_BASENAME, Constants.PERSON_ICON, ImageType.PNG);
    }

    @Override
    public void saveToMemento() {
        mementoState = true;

        memento = Managers.getManager(IPropertiesManager.class).createMemento(this);

        if (memento == null) {
            mementoState = false;
        }
    }

    @Override
    public void restoreMemento() {
        if (mementoState) {
            Managers.getManager(IPropertiesManager.class).restoreMemento(this, memento);
        }
    }
}