package org.jtheque.films.services.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.DataContainer;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.services.impl.utils.Filmography;
import org.jtheque.films.view.impl.fb.ActorFormBean;

import java.util.List;

/**
 * A service for the actor functions.
 *
 * @author Baptiste Wicht
 */
public interface IActorService extends DataContainer<ActorImpl> {
    String DATA_TYPE = "Actors";

    /**
     * Return an empty actor.
     *
     * @return An empty actor.
     */
    ActorImpl getEmptyActor();

    /**
     * Return the filmography of the actor.
     *
     * @param actor The actor.
     * @return The filmography of the actor.
     */
    Filmography getFilmography(ActorImpl actor);

    /**
     * Create the actor.
     *
     * @param actor The actor to create.
     */
    void create(ActorImpl actor);

    /**
     * Save the actor.
     *
     * @param actor The actor to save.
     */
    void save(ActorImpl actor);

    /**
     * Edit the actor.
     *
     * @param actor The actor to edit.
     * @param infos The informations of the view.
     */
    void edit(ActorImpl actor, ActorFormBean infos);

    /**
     * Indicate if the service has nos actors.
     *
     * @return true if there is no actors else false.
     */
    boolean hasNoActor();

    /**
     * Delete the actor.
     *
     * @param actor The actor to delete.
     * @return true if the actor has been deleted else false.
     */
    boolean delete(ActorImpl actor);

    /**
     * Return all the actors.
     *
     * @return A List containing all the actors.
     */
    List<ActorImpl> getActors();

    /**
     * Indicate if an actor exists or not.
     *
     * @param actor The actor to test.
     * @return true if the actor exists else false.
     */
    boolean exist(ActorImpl actor);

    /**
     * Return the actor denoted by this firstname and name.
     *
     * @param firstName The first name of the actor.
     * @param name      The name of the actor.
     * @return The actor.
     */
    ActorImpl getActor(String firstName, String name);


    /**
     * Indicate if an actor with this firstname and name exist or not.
     *
     * @param firstName The first name of the actor.
     * @param name      The name of the actor.
     * @return true if the actor exists else false.
     */
    boolean exist(String firstName, String name);
}