package org.jtheque.films.services.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.DataContainer;
import org.jtheque.films.persistence.od.RealizerImpl;

import java.util.List;

/**
 * A service for the realizers functions.
 *
 * @author Baptiste Wicht
 */
public interface IRealizersService extends DataContainer<RealizerImpl> {
    String DATA_TYPE = "Realizers";

    /**
     * Return an empty realizer.
     *
     * @return An empty realizer.
     */
    RealizerImpl getEmptyRealizer();

    /**
     * Return the default realizer.
     *
     * @return The default realizer.
     */
    RealizerImpl getDefaultRealizer();

    /**
     * Return all the realizers.
     *
     * @return All the realizers.
     */
    List<RealizerImpl> getRealizers();

    /**
     * Delete the realizer.
     *
     * @param realizer The realizer to delete.
     * @return true if the realilzer has been deleted else false.
     */
    boolean delete(RealizerImpl realizer);

    /**
     * Indicate if a realizer exists with the firstname and name.
     *
     * @param firstname The firstname.
     * @param name      The name.
     * @return true if the realizer exists else false.
     */
    boolean exists(String firstname, String name);

    /**
     * Return the realizer with this name and firstname.
     *
     * @param firstname The firstname.
     * @param name      The name.
     * @return The realizer.
     */
    RealizerImpl getRealizer(String firstname, String name);

    /**
     * Create the realizer.
     *
     * @param realizer The realizer to create.
     */
    void create(RealizerImpl realizer);

    /**
     * Indicate if the realizer exists or not.
     *
     * @param realizer The realizer to test.
     * @return true if the realizer exist else false.
     */
    boolean exists(RealizerImpl realizer);

    /**
     * Indicate if there is no realizers.
     *
     * @return true if there is no realizers else false.
     */
    boolean hasNoRealizers();

    /**
     * Save the realizer.
     *
     * @param realizer The realizer to save.
     */
    void save(RealizerImpl realizer);
}