package org.jtheque.films.services.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.core.utils.db.EntityUtils;
import org.jtheque.films.persistence.dao.able.IDaoActors;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.films.services.able.INotesService;
import org.jtheque.films.services.impl.utils.Filmography;
import org.jtheque.films.view.impl.fb.ActorFormBean;
import org.jtheque.primary.services.able.ICountriesService;

import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * The implementation of the actor service.
 *
 * @author Baptiste Wicht
 */
public final class ActorService implements IActorService {
    /* Variables */
    private ActorImpl emptyActor;

    @Resource
    private ICountriesService countriesService;

    @Resource
    private INotesService notesService;

    @Resource
    private IDaoActors daoActors;

    @Resource
    private IFilmsService filmsService;


    @Override
    @Transactional
    public void edit(ActorImpl actor, ActorFormBean infos) {
        actor.setName(infos.getName());
        actor.setFirstName(infos.getFirstName());
        actor.setNote(infos.getNote());
        actor.setTheCountry(infos.getCountry());

        daoActors.save(actor);
    }

    @Override
    @Transactional
    public void create(ActorImpl actor) {
        daoActors.create(actor);
    }

    @Override
    @Transactional
    public void save(ActorImpl actor) {
        daoActors.save(actor);
    }

    @Override
    @Transactional
    public boolean delete(ActorImpl actor) {
        return daoActors.delete(actor);
    }

    @Override
    public boolean hasNoActor() {
        return daoActors.getActors().isEmpty();
    }

    @Override
    public List<ActorImpl> getActors() {
        return daoActors.getActors();
    }

    @Override
    public boolean exist(ActorImpl actor) {
        return daoActors.exist(actor);
    }

    @Override
    public ActorImpl getActor(String firstName, String name) {
        return daoActors.getActor(firstName, name);
    }

    @Override
    public boolean exist(String firstname, String name) {
        return daoActors.exists(firstname, name);
    }

    @Override
    public List<ActorImpl> getDatas() {
        return daoActors.getActors();
    }

    @Override
    public void addDataListener(DataListener listener) {
        daoActors.addDataListener(listener);
    }

    @Override
    public ActorImpl getEmptyActor() {
        if (emptyActor == null) {
            emptyActor = new ActorImpl();

            emptyActor.setName("");
            emptyActor.setFirstName("");
            emptyActor.setNote(notesService.getDefaultNote());
            emptyActor.setTheCountry(countriesService.getDefaultCountry());
        }

        return emptyActor;
    }

    @Override
    public Filmography getFilmography(ActorImpl actor) {
        Filmography filmo = new Filmography();

        filmo.setActor(actor.getAffichableText());

        List<String> films = new ArrayList<String>(15);

        for (FilmImpl film : filmsService.getFilms()) {
            if (EntityUtils.containsID(film.getActors(), actor.getId())) {
                films.add(film.getTitle());
            }
        }

        filmo.setFilms(films);

        return filmo;
    }

    @Override
    @Transactional
    public void clearAll() {
        daoActors.clearAll();
    }

    @Override
    public String getDataType() {
        return DATA_TYPE;
    }
}