package org.jtheque.films.services.impl.utils.file.exports;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.films.services.impl.utils.search.Search;
import org.jtheque.films.utils.Constants.Files.FileType;
import org.jtheque.primary.od.abstraction.Data;

/**
 * An Exporter.
 *
 * @author Baptiste Wicht
 */
public interface Exporter {
    /**
     * Indicate if the exporter can export to a file format.
     *
     * @param fileType The file format destination.
     * @return true if the exporter can export to this file type else false.
     */
    boolean canExportTo(FileType fileType);

    /**
     * Export to the file path.
     *
     * @param path The file path.
     */
    void export(String path);

    /**
     * Set the search. The search is used to define which datas are concerned by the export.
     *
     * @param search The search containing the datas of the export.
     */
    void setSearch(Search<? extends Data> search);

    /**
     * Return the search of the export.
     *
     * @return The search.
     */
    Search<? extends Data> getSearch();
}