package org.jtheque.films.services.impl.utils.file.jt.writer;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.file.able.BasicDataSource;
import org.jtheque.core.managers.file.IFileManager;
import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.utils.bean.IntDate;
import org.jtheque.utils.io.FileUtils;
import org.jtheque.core.utils.file.jt.JTFileWriter;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.impl.utils.file.jt.sources.JTFDataSource;
import org.jtheque.films.utils.Constants;
import org.jtheque.primary.od.CountryImpl;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.od.KindImpl;
import org.jtheque.primary.od.TypeImpl;

import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Collection;
import java.util.HashSet;

/**
 * Cette classe reprsente un writer de fichier JTF.
 *
 * @author Baptiste Wicht
 */
public final class JTFFileWriter extends JTFileWriter {
    @Override
    public void writeFile(DataOutputStream stream, BasicDataSource source) {
        JTFDataSource dataSource = (JTFDataSource) source;

        try {
            stream.writeUTF(FileUtils.encryptKey(Constants.Files.JT.JTKEY));
            stream.writeUTF(dataSource.getVersion().getVersion());
            stream.writeInt(dataSource.getFileVersion());
            stream.writeInt(IntDate.today().getDate());

            stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);

            FilmImpl film = dataSource.getFilm();

            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(film.getTitle()));
            stream.writeInt(film.getYear());
            stream.writeInt(film.getDuration());
            stream.writeInt(film.getNote().getValue().intValue());
            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(film.getResume()));
            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(film.getComment()));

            stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);

            Collection<CountryImpl> countries = new HashSet<CountryImpl>(10);
            
            writeActors(stream, film, countries);
            writeRealizer(stream, dataSource, film, countries);
            writeLanguage(stream, dataSource, film);
            writeKinds(stream, film);
            writeType(stream, dataSource, film);
            writeCountries(stream, countries);
        } catch (IOException e) {
            Managers.getManager(ILoggingManager.class).getLogger(getClass()).exception(e);
        } finally {
            FileUtils.close(stream);
        }
    }

    private void writeActors(DataOutputStream stream, FilmImpl film, Collection<CountryImpl> countries) throws IOException {
        if (film.hasActors()) {
            stream.writeInt(Constants.Files.JT.NOCONTENT);
        } else {
            stream.writeInt(Constants.Files.JT.CONTENT);

            boolean first = true;

            for (ActorImpl acteur : film.getActors()) {
                if (first) {
                    first = false;
                } else {
                    stream.writeLong(Constants.Files.JT.JTINTERNSEPARATOR);
                }

                stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(acteur.getName()));
                stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(acteur.getFirstName()));
                stream.writeInt(acteur.getTheCountry().getId());
                stream.writeInt(acteur.getNote().getValue().intValue());

                countries.add(acteur.getTheCountry());
            }
        }

        stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);
    }

    private void writeRealizer(DataOutputStream stream, JTFDataSource dataSource, FilmImpl film, Collection<CountryImpl> countries) throws IOException {
        if (film.hasRealizer()) {
            stream.writeInt(Constants.Files.JT.NOCONTENT);
        } else {
            stream.writeInt(Constants.Files.JT.CONTENT);

            RealizerImpl realisateur = dataSource.getFilm().getTheRealizer();

            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(realisateur.getName()));
            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(realisateur.getFirstName()));
            stream.writeInt(realisateur.getTheCountry().getId());
            stream.writeInt(realisateur.getNote().getValue().intValue());

            if (realisateur.hasCountry()) {
                countries.add(realisateur.getTheCountry());
            }
        }

        stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);
    }

    private void writeLanguage(DataOutputStream stream, JTFDataSource dataSource, FilmImpl film) throws IOException {
        if (film.getTheLanguage() == null) {
            stream.writeInt(Constants.Files.JT.NOCONTENT);
        } else {
            stream.writeInt(Constants.Files.JT.CONTENT);

            LanguageImpl langue = dataSource.getFilm().getTheLanguage();

            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(langue.getName()));
        }

        stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);
    }

    private void writeKinds(DataOutputStream stream, FilmImpl film) throws IOException {
        if (film.hasKinds()) {
            stream.writeInt(Constants.Files.JT.NOCONTENT);
        } else {
            stream.writeInt(Constants.Files.JT.CONTENT);

            boolean first = true;

            for (KindImpl kind : film.getKinds()) {
                if (first) {
                    first = false;
                } else {
                    stream.writeLong(Constants.Files.JT.JTINTERNSEPARATOR);
                }

                stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(kind.getName()));
            }
        }

        stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);
    }

    private void writeType(DataOutputStream stream, JTFDataSource dataSource, FilmImpl film) throws IOException {
        if (film.getTheType() == null) {
            stream.writeInt(Constants.Files.JT.NOCONTENT);
        } else {
            stream.writeInt(Constants.Files.JT.CONTENT);

            TypeImpl type = dataSource.getFilm().getTheType();

            stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(type.getName()));
        }

        stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);
    }

    private void writeCountries(DataOutputStream stream, Collection<CountryImpl> countries) throws IOException {
        if (countries.isEmpty()) {
            stream.writeInt(Constants.Files.JT.NOCONTENT);
        } else {
            stream.writeInt(Constants.Files.JT.CONTENT);

            boolean first = true;

            for (CountryImpl country : countries) {
                if (first) {
                    first = false;
                } else {
                    stream.writeLong(Constants.Files.JT.JTINTERNSEPARATOR);
                }

                stream.writeInt(country.getId());
                stream.writeUTF(Managers.getManager(IFileManager.class).formatUTFToWrite(country.getName()));
            }
        }

        stream.writeLong(Constants.Files.JT.JTCATEGORYSEPARATOR);
    }
}