package org.jtheque.films.services.impl.utils.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.db.Note;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.primary.od.CountryImpl;

/**
 * A search of actors.
 *
 * @author Baptiste Wicht
 */
public final class ActorSearch extends AbstractSearch<ActorImpl> {
    private boolean mustCheckCountry;
    private boolean mustCheckNote;

    /* Search's criteria */
    private Note note;
    private CountryImpl country;

    /**
     * Construct a new <code>ActorSearch</code>.
     */
    public ActorSearch() {
        super();

        setSearcher(new ActorSearcher());
    }

    /**
     * Return the country of the search.
     *
     * @return the country
     */
    public CountryImpl getCountry() {
        return country;
    }

    /**
     * Set the country of the search.
     *
     * @param country the country to set
     */
    public void setCountry(CountryImpl country) {
        this.country = country;
    }

    /**
     * Indicate if we must check the country for the search.
     *
     * @return <code>true</code> if we must check country else <code>false</code>.
     */
    public boolean isMustCheckCountry() {
        return mustCheckCountry;
    }

    /**
     * Set if we must check the country or not.
     *
     * @param mustCheckCountry the mustCheckCountry to set
     */
    public void setMustCheckCountry(boolean mustCheckCountry) {
        this.mustCheckCountry = mustCheckCountry;
    }

    /**
     * Indicate if we must check the note for the search.
     *
     * @return <code>true</code> if we must check note else <code>false</code>.
     */
    public boolean isMustCheckNote() {
        return mustCheckNote;
    }

    /**
     * Set if we must check the note or not.
     *
     * @param mustCheckNote the mustCheckNote to set
     */
    public void setMustCheckNote(boolean mustCheckNote) {
        this.mustCheckNote = mustCheckNote;
    }

    /**
     * Return the note of the search.
     *
     * @return the note
     */
    public Note getNote() {
        return note;
    }

    /**
     * Set the note of the search.
     *
     * @param note The searched note
     */
    public void setNote(Note note) {
        this.note = note;
    }
}