package org.jtheque.films.services.impl.utils.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.services.able.IActorService;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * A searcher for the actors. This classe permit a search of actors with an objet Search.
 *
 * @author Baptiste Wicht
 */
public final class ActorSearcher implements Searcher<ActorImpl> {
    @Resource
    private IActorService actorService;

    /**
     * Construct a new ActorSearcher.
     */
    public ActorSearcher() {
        super();

        Managers.getManager(IBeansManager.class).inject(this);
    }

    @Override
    public List<ActorImpl> search(Search<ActorImpl> research) {
        List<ActorImpl> actors = actorService.getActors();

        List<ActorImpl> list = new ArrayList<ActorImpl>(actors.size() / 2);
        ActorSearch search = (ActorSearch) research;

        for (ActorImpl actor : actors) {
            boolean correct = true;

            if (search.isMustCheckNote() && !actor.getNote().equals(search.getNote())) {
                correct = false;
            }

            if (search.isMustCheckCountry() && !actor.getTheCountry().equals(search.getCountry())) {
                correct = false;
            }

            if (correct) {
                list.add(actor);
            }
        }

        return list;
    }
}