package org.jtheque.films.services.impl.utils.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.od.abstraction.Data;

import java.util.List;

/**
 * A search. A search contains results of a research and the different parameters of the original research.
 *
 * @author Baptiste Wicht
 * @param <T> The type of the research.
 */
public interface Search<T extends Data> {
    /**
     * Return the results of the research.
     *
     * @return The results of the search.
     */
    List<T> getResults();

    /**
     * Set the results of the search.
     *
     * @param results The results of the research.
     */
    void setResults(List<T> results);

    /**
     * Return the unique result of the search.
     *
     * @return The unique result of the search.
     */
    T getResult();

    /**
     * Return the searcher for this research. It seems the object who can effectuate the research with the
     * parameters contained in the search.
     *
     * @return The Searcher.
     */
    Searcher<T> getSearcher();

    /**
     * Set the searcher of the search.
     *
     * @param searcher The Searcher.
     */
    void setSearcher(Searcher<T> searcher);

    /**
     * Set the result of the search.
     *
     * @param result The result.
     */
    void setResult(T result);
}