package org.jtheque.films.view.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.primary.view.impl.listeners.CurrentObjectListener;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.films.view.impl.fb.FilmFormBean;

import javax.swing.DefaultListModel;
import javax.swing.JComponent;

import java.util.List;

/**
 * @author Baptiste Wicht
 */
public interface IInfosActorsView extends CurrentObjectListener {

    /**
     * Return the model of the list of actors.
     *
     * @return The <code>DefaultListModel</code> associated to the list of actors.
     */
    DefaultListModel getActorsModel();

    /**
     * Return the actors for film model.
     *
     * @return The actors for film model.
     */
    DefaultListModel getActorsForFilmModel();

    /**
     * Return the indices of the selected actors.
     *
     * @return An array containing the indices of the selected actors.
     */
    int[] getSelectedActorsIndices();

    /**
     * Return the indices of the selected actors for film.
     *
     * @return An array containing the indices of the selected actors for film.
     */
    int[] getSelectedActorsForFilmIndices();

    /**
     * Validate the view.
     *
     * @param errors The errors list to fill.
     */
    void validate(List<JThequeError> errors);
    
    /**
     * Fill the formbean.
     *
     * @param fb The formbean to fill.
     */
    void fillFilm(FilmFormBean fb);

    void setEnabled(boolean enabled);

    JComponent getImpl();
}
