package org.jtheque.films.view.impl.fb;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.db.Note;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.persistence.od.abstraction.Film;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.od.SagaImpl;
import org.jtheque.primary.od.TypeImpl;
import org.jtheque.primary.od.KindImpl;

import java.util.HashSet;
import java.util.Set;

/**
 * A film formbean. This formbean contains all the informations of a film. It is used by the inteface
 * to pass data to the controller.
 *
 * @author Baptiste Wicht
 */
public final class FilmFormBean implements FormBean {
    private String title;
    private TypeImpl type;
    private RealizerImpl realizer;
    private LanguageImpl language;
    private SagaImpl saga;
    private int year;
    private int duration;
    private Note note;
    private String resume;
    private String comment;
    private String image;
    private String filePath;
    private Set<ActorImpl> actors = new HashSet<ActorImpl>(15);
    private Set<KindImpl> kinds = new HashSet<KindImpl>(5);

    /**
     * Set the title of the film.
     *
     * @param title The title to set.
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * Cette mthode retourne le titre du film.
     *
     * @return Le titre du film
     */
    public String getTitle() {
        return title;
    }

    /**
     * Cette mthode modifie le type du film.
     *
     * @param type le nouveau type du film
     */
    public void setType(TypeImpl type) {
        this.type = type;
    }

    /**
     * Cette mthode retourne le type du film.
     *
     * @return Le type du film
     */
    public TypeImpl getType() {
        return type;
    }

    /**
     * Cette mthode modifie l'anne du film.
     *
     * @param annee la nouvelle anne du film
     */
    public void setYear(int annee) {
        year = annee;
    }

    /**
     * Cette mthode retourne l'anne du film.
     *
     * @return L'anne du film
     */
    public int getYear() {
        return year;
    }

    /**
     * Cette mthode modifie la dure du film.
     *
     * @param duree la nouvelle dure du film
     */
    public void setDuration(int duree) {
        duration = duree;
    }

    /**
     * Cette mthode retourne la dure du film.
     *
     * @return La dure du film
     */
    public int getDuration() {
        return duration;
    }

    /**
     * Cette mthode modifie le ralisateur du film.
     *
     * @param realisateur le nouveau ralisateur
     */
    public void setRealizer(RealizerImpl realisateur) {
        realizer = realisateur;
    }

    /**
     * Cette mthode retourne le ralisateur du film.
     *
     * @return Le rasaliteur du film
     */
    public RealizerImpl getRealizer() {
        return realizer;
    }

    /**
     * Cette mthode modifie la langue du film.
     *
     * @param langue la nouvelle langue du film
     */
    public void setLanguage(LanguageImpl langue) {
        language = langue;
    }

    /**
     * Cette mthode retourne la langue du film.
     *
     * @return La langue du film
     */
    public LanguageImpl getLanguage() {
        return language;
    }

    /**
     * Set the note of the realizer.
     *
     * @param note The note to set.
     */
    public void setNote(Note note) {
        this.note = note;
    }

    /**
     * Return the note of the realizer.
     *
     * @return the note.
     */
    public Note getNote() {
        return note;
    }

    /**
     * Cette mthode permet de modifier le commentaire du film.
     *
     * @param commentaire Le nouveau commentaire
     */
    public void setComment(String commentaire) {
        comment = commentaire;
    }

    /**
     * Cette mthode retourne le commentaire sur le film.
     *
     * @return Le commentaire sur le film
     */
    public String getComment() {
        return comment;
    }

    /**
     * Cette mthode modifie le rsum du film.
     *
     * @param resume Le nouveau rsum
     */
    public void setResume(String resume) {
        this.resume = resume;
    }

    /**
     * Cette mthode retourne le rsum du film.
     *
     * @return Le rsum
     */
    public String getResume() {
        return resume;
    }

    /**
     * Cette mthode modifie le chemin de l'image du film.
     *
     * @param imagePath Le nouveau chemin
     */
    public void setImage(String imagePath) {
        image = imagePath;
    }

    /**
     * Cette mthode retourne le chemin vers le film.
     *
     * @return Le chemin vers le film
     */
    public String getImage() {
        return image;
    }

    /**
     * Cette mthode permet de rcuprer la liste des acteurs du film.
     *
     * @return La liste des acteurs du film
     */
    public Set<ActorImpl> getActors() {
        return actors;
    }

    /**
     * Cette mthode permet de modifier les acteurs d'un film.
     *
     * @param actors La nouvelle liste d'acteurs du film
     */
    public void setActors(Set<ActorImpl> actors) {
        this.actors = new HashSet<ActorImpl>(actors);
    }

    /**
     * Return the saga of the film.
     *
     * @return The saga of the film.
     */
    public SagaImpl getSaga() {
        return saga;
    }

    /**
     * Set the saga of the film.
     *
     * @param saga The saga of the film.
     */
    public void setSaga(SagaImpl saga) {
        this.saga = saga;
    }

    /**
     * Return the path to the file.
     *
     * @return The path to the file.
     */
    public String getFilePath() {
        return filePath;
    }

    /**
     * Set the file path.
     *
     * @param filePath The path to the file.
     */
    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }

    /**
     * Return all the kinds of the film.
     *
     * @return A List containing all the kinds of the film.
     */
    public Set<KindImpl> getKinds() {
        return kinds;
    }

    /**
     * Set the kinds of the film.
     *
     * @param kinds The kinds of the film.
     */
    public void setKinds(Set<KindImpl> kinds) {
        this.kinds = new HashSet<KindImpl>(kinds);
    }

    /**
     * Fill a film with the info of the formbean.
     *
     * @param film The film to fill.
     */
    public void fillFilm(Film film) {
        //On complte les donnes du film avec les donnes de cette interface
        film.setTitle(title);
        film.setKinds(kinds);
        film.setTheType(type);
        film.setComment(comment);
        film.setNote(note);
        film.setActors(actors);
        film.setTheRealizer(realizer);
        film.setTheLanguage(language);
        film.setYear(year);
        film.setDuration(duration);
        film.setResume(resume);
        film.setFilePath(filePath);
    }
}