package org.jtheque.films.view.impl.frames;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXTable;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.films.view.able.ILendingsView;
import org.jtheque.films.view.impl.editors.DataCellEditor;
import org.jtheque.films.view.impl.menus.JMenuBarLendings;
import org.jtheque.films.view.impl.models.table.LendingsTableModel;
import org.jtheque.primary.services.able.IBorrowersService;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import java.awt.Container;
import java.awt.Frame;
import java.util.ArrayList;
import java.util.List;

/**
 * Cette classe est la classe d'interface graphique permettant d'afficher les prts.
 *
 * @author Baptiste Wicht
 */
public final class LendingsView extends SwingDialogView implements ILendingsView {
    private static final long serialVersionUID = 6554684772063503187L;

    private LendingsTableModel model;
    private JXTable tablePrets;

    @Resource
    private IBorrowersService borrowersService;

    @Resource
    private IFilmsService filmsService;

    private JThequeAction lendAction;
    private JThequeAction returnAction;
    private JThequeAction closeAction;
        
    /**
     * Construct a new <code>JFrameLendings</code>.
     * 
     * @param parent The parent frame. 
     */
    public LendingsView(Frame parent) {
        super(parent);
    }

    @Override
    @PostConstruct
    public void build() {
        setJMenuBar(new JMenuBarLendings());
        setTitleKey("lendings.view.title");
        setContentPane(buildContentPane());
        setResizable(true);

        pack();
        
        SwingUtils.centerFrame(this);
    }

    /**
     * Build the content pane.
     *
     * @return the content pane.
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();

        model = new LendingsTableModel();
        setTableHeader();

        tablePrets = new JXTable(model);
        tablePrets.getColumn(1).setCellEditor(new DataCellEditor(filmsService));
        tablePrets.getColumn(2).setCellEditor(new DataCellEditor(borrowersService));
        tablePrets.getTableHeader().setReorderingAllowed(false);
        tablePrets.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        tablePrets.setAutoResizeMode(JTable.AUTO_RESIZE_LAST_COLUMN);
        tablePrets.setColumnControlVisible(true);
        setIdColumnNotVisible();
        tablePrets.packAll();

        builder.addScrolled(tablePrets, builder.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 0, -1, 1.0, 1.0));
        
        builder.addButtonBar(builder.gbcSet(0, 1, GridBagUtils.HORIZONTAL, 0, 0), 
                lendAction, returnAction, closeAction);
        
        return builder.getPanel();
    }

    @Override
    public List<Integer> getSelectedLendingsID() {
        List<Integer> lendings = new ArrayList<Integer>(tablePrets.getSelectedRowCount());

        int[] rows = tablePrets.getSelectedRows();

        if (rows.length > 0) {
            for (int row : rows) {
                lendings.add((Integer) model.getValueAt(tablePrets.convertRowIndexToModel(row), 0));
            }
        }

        return lendings;
    }

    @Override
    public void refreshText() {
        super.refreshText();

        setTableHeader();
        setIdColumnNotVisible();
    }

    /**
     * Set the table header.
     */
    private void setTableHeader() {
        model.setHeader(new String[]{
                getMessage("lendings.view.table.id"),
                getMessage("lendings.view.table.film"),
                getMessage("lendings.view.table.borrower"),
                getMessage("lendings.view.table.date")});
    }

    /**
     * Specify that the column "ID" is not visible.
     */
    private void setIdColumnNotVisible() {
        tablePrets.getColumnExt(getMessage("lendings.view.table.id")).setVisible(false);
    }

    @Override
    protected void validate(List<JThequeError> errors) {
    }

    public void setLendAction(JThequeAction lendAction) {
        this.lendAction = lendAction;
    }

    public void setReturnAction(JThequeAction returnAction) {
        this.returnAction = returnAction;
    }

    public void setCloseAction(JThequeAction closeAction) {
        this.closeAction = closeAction;
    }
}