package org.jtheque.films.view.impl.frames;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.able.controller.Controller;
import org.jtheque.core.managers.view.impl.components.InfiniteWaitFigure;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.films.services.impl.utils.search.Search;
import org.jtheque.films.view.able.ISearchView;
import org.jtheque.films.view.impl.panels.search.JPanelSearch;
import org.jtheque.films.controllers.able.IFilmController;
import org.jtheque.films.controllers.able.IActorController;
import org.jtheque.films.controllers.able.IRealizerController;
import org.jtheque.primary.od.abstraction.Data;

import javax.swing.JFrame;
import javax.annotation.PostConstruct;

import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/**
 * The GUI of search. From this view, we can search datas in JTheque.
 *
 * @author Baptiste Wicht
 */
public final class SearchView extends SwingDialogView implements ISearchView {
    private static final long serialVersionUID = -8315962232919880990L;

    /* Research's panels */
    private JPanelSearch filmSearchPanel;
    private JPanelSearch actorSearchPanel;
    private JPanelSearch realizerSearchPanel;
    
    private JPanelSearch currentPanel;

    private JThequeAction validateAction;
    private JThequeAction closeAction;
    
    /**
     * Ce constructeur cre et initiliase l'interface graphique.
     * 
     * @param parent The parent frame. 
     */
    public SearchView(Frame parent) {
        super(parent);
    }

    @Override
    @PostConstruct
    public void build() {
        currentPanel = filmSearchPanel;
        
        setIconImage(getDefaultWindowIcon());
        setResizable(true);
        setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
        setWaitFigure(new InfiniteWaitFigure());

        reload();

        SwingUtils.centerFrame(this);
    }

    /**
     * Reload the GUI.
     */
    private void reload() {
        setTitle(currentPanel.getTitle());
        setContentPane(buildContentPane());

        pack();
    }

    /**
     * Build the content pane.
     *
     * @return the content pane.
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();

        builder.add(currentPanel, builder.gbcSet(0, 0));
        
        builder.addButtonBar(builder.gbcSet(0, 1), validateAction, closeAction);
        
        return builder.getPanel();
    }

    @Override
    public Search<? extends Data> buildSearch() {
        return currentPanel.getSearch();
    }

    @Override
    public void setContentController(Controller content) {
        if (IFilmController.class.isAssignableFrom(content.getClass())) {
            currentPanel = filmSearchPanel;
        }
        
        if (IActorController.class.isAssignableFrom(content.getClass())) {
            currentPanel = actorSearchPanel;
        }
        
        if (IRealizerController.class.isAssignableFrom(content.getClass())) {
            currentPanel = realizerSearchPanel;
        }
        
        reload();

        Managers.getManager(IViewManager.class).refresh(this);
    }

    @Override
    protected void validate(List<JThequeError> errors) {
    }
    
    public void setValidateAction(JThequeAction validateAction) {
        this.validateAction = validateAction;
    }

    public void setCloseAction(JThequeAction closeAction) {
        this.closeAction = closeAction;
    }

    public void setFilmSearchPanel(JPanelSearch filmSearchPanel) {
        this.filmSearchPanel = filmSearchPanel;
    }

    public void setActorSearchPanel(JPanelSearch actorSearchPanel) {
        this.actorSearchPanel = actorSearchPanel;
    }

    public void setRealizerSearchPanel(JPanelSearch realizerSearchPanel) {
        this.realizerSearchPanel = realizerSearchPanel;
    }
}