package org.jtheque.films.view.impl.frames;

import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.managers.view.impl.components.panel.FileChooserPanel;
import org.jtheque.core.managers.view.impl.frame.abstraction.SwingDialogView;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.utils.ui.SwingUtils;
import org.jtheque.utils.ui.GridBagUtils;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.films.view.able.IVideoFileView;
import org.jtheque.primary.view.impl.models.DataContainerCachedComboBoxModel;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JComponent;
import java.awt.Container;
import java.awt.Frame;
import java.util.List;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @author Baptiste Wicht
 */
public final class VideoFileView extends SwingDialogView implements IVideoFileView {
    private DataContainerCachedComboBoxModel<FilmImpl> model;
    private FileChooserPanel fieldFile;

    @Resource
    private IFilmsService filmsService;
    
    private JThequeAction validateAction;
    private JThequeAction closeAction;

    /**
     * Construct a new VideoFileView modal to his parent view.
     * 
     * @param parent The parent frame. 
     */
    public VideoFileView(Frame parent) {
        super(parent);
    }

    @Override
    @PostConstruct
    public void build() {
        setContentPane(buildContentPane());
        setResizable(true);
        pack();

        SwingUtils.centerFrame(this);
    }

    /**
     * Build the content pane.
     *
     * @return The builded content pane.
     */
    private Container buildContentPane() {
        PanelBuilder builder = new PanelBuilder();
        
        fieldFile = new FileChooserPanel();
        fieldFile.setTextKey("video.file.view.file");
        SwingUtils.addFieldValidateAction(fieldFile, validateAction);

        builder.add(fieldFile, builder.gbcSet(0, 0, GridBagUtils.HORIZONTAL, 2, 1));

        builder.addI18nLabel("video.file.view.film", builder.gbcSet(0, 1));

        model = new DataContainerCachedComboBoxModel<FilmImpl>(filmsService);
        
        JComponent combo = builder.addComboBox(model, builder.gbcSet(1, 1));
        SwingUtils.addFieldValidateAction(combo, validateAction);

        builder.addButtonBar(builder.gbcSet(0, 2, GridBagUtils.HORIZONTAL, 2, 1), validateAction, closeAction);
        
        return builder.getPanel();
    }

    @Override
    protected void validate(List<JThequeError> errors) {
    }

    @Override
    public String getFilePath() {
        return fieldFile.getFilePath();
    }

    @Override
    public FilmImpl getFilm() {
        return model.getSelectedData();
    }

    public void setValidateAction(JThequeAction validateAction) {
        this.validateAction = validateAction;
    }

    public void setCloseAction(JThequeAction closeAction) {
        this.closeAction = closeAction;
    }
}