package org.jtheque.films.view.impl.models.table;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.log.ILoggingManager;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.core.managers.persistence.DataEvent;
import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.utils.bean.IntDate;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.persistence.dao.able.IDaoFilms;
import org.jtheque.films.services.able.IFilmsService;
import org.jtheque.primary.od.BorrowerImpl;
import org.jtheque.primary.od.LendingImpl;
import org.jtheque.primary.services.able.ILendingsService;

import javax.annotation.Resource;
import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import javax.swing.table.AbstractTableModel;

/**
 * Cette classe reprsente un modle de donnes pour l'affichage du tableau des emprunts.
 *
 * @author Baptiste Wicht
 */
public final class LendingsTableModel extends AbstractTableModel implements TableModelListener, DataListener {
    private static final long serialVersionUID = 1L;

    /**
     * The differents columns of the lendings table.
     *
     * @author Baptiste Wicht
     */
    public interface Columns {
        int ID = 0;
        int FILM = 1;
        int BORROWER = 2;
        int DATE = 3;
    }

    private String[] headers;

    @Resource
    private ILendingsService lendingsService;

    @Resource
    private IDaoFilms daoFilms;

    /**
     * Construct a new <code>LendingsTableModel</code>.
     */
    public LendingsTableModel() {
        super();

        addTableModelListener(this);

        Managers.getManager(IBeansManager.class).inject(this);
        
        lendingsService.addDataListener(this);
    }

    /**
     * Modifie les headers de la JTable.
     *
     * @param headers les nouveaux headers qu'il faut mettre
     */
    public void setHeader(String[] headers) {
        this.headers = headers.clone();

        fireTableStructureChanged();
    }

    @Override
    public int getColumnCount() {
        return headers.length;
    }

    @Override
    public int getRowCount() {
        return lendingsService.getLendings().size();
    }

    @Override
    public Object getValueAt(int rowIndex, int columnIndex) {
        Object value;

        switch (columnIndex) {
            case Columns.ID:
                value = lendingsService.getLendings().get(rowIndex).getId();
                break;
            case Columns.FILM:
                value = daoFilms.getFilm(lendingsService.getLendings().get(rowIndex).getTheOther());
                break;
            case Columns.BORROWER:
                value = lendingsService.getLendings().get(rowIndex).getTheBorrower();
                break;
            case Columns.DATE:
                value = lendingsService.getLendings().get(rowIndex).getDate();
                break;
            default:
                value = "";
                break;
        }

        return value;
    }

    @Override
    public void setValueAt(Object value, int column, int row) {
        if (value != null) {
            LendingImpl lending = lendingsService.getLending(row);

            switch (column) {
                case Columns.FILM:
                    lending.setTheOther(((FilmImpl) value).getId());
                    break;
                case Columns.BORROWER:
                    lending.setTheBorrower((BorrowerImpl) value);
                    break;
                case Columns.DATE:
                    lending.setDate(new IntDate((Integer) value));
                    break;
                default:
                    Managers.getManager(ILoggingManager.class).getLogger(getClass()).debug("Anormal entry in switch clause. ");
                    break;
            }

            fireTableCellUpdated(column, row);
        }
    }

    @Override
    public String getColumnName(int column) {
        return headers[column];
    }

    @Override
    public boolean isCellEditable(int row, int column) {
        return false;
    }

    @Override
    public void tableChanged(TableModelEvent event) {
        //Si c'est une modification et si c'est un event sur une colonne en particulier et pas sur toutes
        if (event.getType() == TableModelEvent.UPDATE &&
                event.getColumn() != -1 &&
                event.getFirstRow() == event.getLastRow()) {
            lendingsService.save(lendingsService.getLending(event.getFirstRow()));
        }
    }

    @Override
    public void dataChanged(DataEvent event) {
        fireTableDataChanged();
    }
}