package org.jtheque.films.view.impl.panels;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXHyperlink;
import org.jdesktop.swingx.JXTitledPanel;
import org.jdesktop.swingx.JXTree;
import org.jdesktop.swingx.border.DropShadowBorder;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.utils.ui.Borders;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.films.controllers.able.IActorController;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.core.utils.ui.constraints.ConstraintManager;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.utils.Constants.Properties.Person;
import org.jtheque.films.view.able.IActorView;
import org.jtheque.films.view.impl.fb.ActorFormBean;
import org.jtheque.films.view.impl.models.ActorsModel;
import org.jtheque.films.view.impl.toolbars.JPanelActorToolBar;
import org.jtheque.primary.od.CountryImpl;
import org.jtheque.primary.services.able.ICountriesService;
import org.jtheque.primary.view.able.ToolbarView;
import org.jtheque.primary.view.impl.components.panels.JThequeTitledPanel;
import org.jtheque.primary.view.impl.components.panels.PrincipalDataPanel;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.primary.view.impl.models.DataContainerCachedComboBoxModel;
import org.jtheque.primary.view.impl.models.NotesComboBoxModel;
import org.jtheque.primary.view.impl.renderers.JThequeTreeCellRenderer;
import org.jtheque.primary.view.impl.renderers.NoteComboRenderer;
import org.jtheque.primary.view.impl.sort.SortManager;
import org.jtheque.utils.ui.GridBagUtils;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JTextField;
import javax.swing.Action;

import java.awt.Font;
import java.util.List;

/**
 * Cette classe est le panel reprsentant les acteurs.
 *
 * @author Baptiste Wicht
 */
public final class ActorView extends PrincipalDataPanel implements IActorView {
    private static final long serialVersionUID = -4304886748651187432L;

    private JXTitledPanel actorPanel;

    private JTextField fieldPrenom;
    private JTextField fieldNom;
    private DataContainerCachedComboBoxModel<CountryImpl> modelCountries;
    private NotesComboBoxModel modelNote;
    private JPanelActorToolBar toolBar;
    private JComboBox comboCountries;
    private JComboBox comboNote;

    private JXTree treeActeurs;
    
    /* Instances */
    private final SortManager sorter = new SortManager();

    @Resource
    private ICountriesService countriesService;
    
    @Resource
    private IActorController actorController;
    
    private JThequeAction newCountryAction;
    private Action sortByNoteAction;
    private Action sortByCountryAction;

    @Override
    @PostConstruct
    public void build() {
        getModel().addDisplayListListener(this);
        
        PanelBuilder builder = new PanelBuilder(this);

        buildPanelListe(builder);
        buildPanelTri(builder);
        buildPanelActeur(builder);

        setBorder(Borders.DIALOG_BORDER);

        addListeners();
        
        selectFirst();
    }
    
    private void addListeners() {
        treeActeurs.addTreeSelectionListener(actorController);

        getModel().addDisplayListListener(this);
        getModel().addCurrentObjectListener(this);
    }

    /**
     * Build the internal panel actor.
     * 
     * @param parent The builder of the frame. 
     */
    private void buildPanelActeur(PanelBuilder parent) {
        actorPanel = new JThequeTitledPanel("actor.view.panel.actor.title");
        actorPanel.setBorder(new DropShadowBorder());
        actorPanel.setTitleFont(actorPanel.getTitleFont().deriveFont(Font.BOLD));
        
        PanelBuilder builder = new PanelBuilder();
        
        builder.add(toolBar, builder.gbcSet(0, 0, GridBagUtils.HORIZONTAL, 0, 1));
        
        builder.addI18nLabel(Person.FIRSTNAME, builder.gbcSet(0, 1));
        
        fieldPrenom = builder.add(new JTextField(20), builder.gbcSet(1, 1, GridBagUtils.NONE, 0, 1));
        ConstraintManager.configure(fieldPrenom, Person.FIRSTNAME);
        fieldPrenom.setEnabled(false);

        builder.addI18nLabel(Person.NAME, builder.gbcSet(0, 2));
        
        fieldNom = builder.add(new JTextField(20), builder.gbcSet(1, 2, GridBagUtils.NONE, 0, 1));
        ConstraintManager.configure(fieldNom, Person.NAME);
        fieldNom.setEnabled(false);

        builder.addI18nLabel(Person.COUNTRY, builder.gbcSet(0, 3));

        modelCountries = new DataContainerCachedComboBoxModel<CountryImpl>(countriesService);
        
        comboCountries = builder.addComboBox(modelCountries, builder.gbcSet(1, 3));
        comboCountries.setEnabled(false);
        
        newCountryAction.setEnabled(false);

        builder.addButton(newCountryAction, builder.gbcSet(2, 3, GridBagUtils.NONE, 0, 1));

        builder.addI18nLabel(Person.NOTE, builder.gbcSet(0, 4));

        modelNote = new NotesComboBoxModel();
        
        comboNote = builder.addComboBox(modelNote, builder.gbcSet(1, 4, GridBagUtils.NONE, GridBagUtils.ABOVE_BASELINE_LEADING, 0, 0, 1.0, 1.0));
        comboNote.setEnabled(false);
        comboNote.setRenderer(new NoteComboRenderer());

        actorPanel.setContentContainer(builder.getPanel());
        
        parent.add(actorPanel, parent.gbcSet(1, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 1, 2, 0.75, 1.0));
    }

    /**
     * Build the internal panel sort.
     * 
     * @param parent The builder of the frame. 
     */
    private void buildPanelTri(PanelBuilder parent) {
        JXTitledPanel panelTri = new JThequeTitledPanel("actor.view.panel.sort.title");
        panelTri.setBorder(new DropShadowBorder());
        panelTri.setTitleFont(panelTri.getTitleFont().deriveFont(Font.BOLD));

        PanelBuilder builder = new PanelBuilder();
        
        JXHyperlink linkTriPays = builder.add(new JXHyperlink(sortByCountryAction), 
                builder.gbcSet(0, 0, GridBagUtils.NONE, GridBagUtils.BASELINE_LEADING, 0, 1, 1.0, 0.0));
        linkTriPays.setClickedColor(linkTriPays.getUnclickedColor());
        
        JXHyperlink linkTriNote = builder.add(new JXHyperlink(sortByNoteAction), 
                builder.gbcSet(0, 1, GridBagUtils.NONE, GridBagUtils.BASELINE_LEADING, 0, 1, 1.0, 0.0));
        linkTriNote.setClickedColor(linkTriNote.getUnclickedColor());

        panelTri.setContentContainer(builder.getPanel());
        
        parent.add(panelTri, parent.gbcSet(0, 1, GridBagUtils.HORIZONTAL, GridBagUtils.FIRST_LINE_START, 0.25, 0.0));
    }

    /**
     * Build the internal panel list.
     * 
     * @param parent The builder of the frame. 
     */
    private void buildPanelListe(PanelBuilder parent) {
        JXTitledPanel panelListe = new JThequeTitledPanel("actor.view.panel.list.title");
        panelListe.setBorder(new DropShadowBorder());
        panelListe.setTitleFont(panelListe.getTitleFont().deriveFont(Font.BOLD));

        PanelBuilder builder = new PanelBuilder();

        setTreeModel(sorter.createInitialModel(IActorService.DATA_TYPE));
        
        treeActeurs = new JXTree(getTreeModel());
        treeActeurs.setCellRenderer(new JThequeTreeCellRenderer());
        treeActeurs.putClientProperty("JTree.lineStyle", "None");

        builder.addScrolled(treeActeurs, builder.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 0, 0, 1.0, 1.0));

        panelListe.setContentContainer(builder.getPanel());
        
        parent.add(panelListe, parent.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 0.25, 1.0));
    }

    /**
     * Cette mthode permet d'indiquer que l'on change d'acteur et donc de mettre  jour les champs.
     *
     * @param current L'acteur slectionn
     */
    private void setCurrentActeur(ActorImpl current) {
        //On modifie le titre
        actorPanel.setTitle(current.getAffichableText());

        //On remplit les champs
        fieldPrenom.setText(current.getFirstName());
        fieldNom.setText(current.getName());
        modelCountries.setSelectedItem(current.getTheCountry());
        modelNote.setSelectedItem(current.getNote());
    }

    @Override
    public ActorFormBean fillActorFormBean() {
        ActorFormBean fb = new ActorFormBean();

        //On complte les donnes du film avec les donnes de cette interface
        fb.setNom(fieldNom.getText());
        fb.setFirstName(fieldPrenom.getText());
        fb.setNote(modelNote.getSelectedNote());
        fb.setCountry(modelCountries.getSelectedData());

        return fb;
    }

    @Override
    public void objectChanged(ObjectChangedEvent event) {
        setCurrentActeur((ActorImpl) event.getObject());
    }

    @Override
    public void setEnabled(boolean enabled) {
        fieldPrenom.setEnabled(enabled);
        fieldNom.setEnabled(enabled);
        comboCountries.setEnabled(enabled);
        comboNote.setEnabled(enabled);
        newCountryAction.setEnabled(enabled);
    }

    @Override
    public ToolbarView getToolbarView() {
        return toolBar;
    }

    @Override
    public String getDataType() {
        return IActorService.DATA_TYPE;
    }

    @Override
    protected JXTree getTree() {
        return treeActeurs;
    }

    @Override
    public JComponent getImpl() {
        return this;
    }

    @Override
    public Integer getPosition() {
        return 2;
    }

    @Override
    public String getTitlekey() {
        return "actor.data.title";
    }

    @Override
    public ActorsModel getModel() {
        return (ActorsModel) super.getModel();
    }

    @Override
    public void clear() {
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        ConstraintManager.validate(Person.NAME, fieldNom.getText(), errors);
        ConstraintManager.validate(Person.FIRSTNAME, fieldPrenom.getText(), errors);
        ConstraintManager.validate(Person.COUNTRY, modelCountries.getSelectedData(), errors);
    }

    @Override
    public JComponent getComponent() {
        return this;
    }

    public void setSortByNoteAction(Action sortByNoteAction) {
        this.sortByNoteAction = sortByNoteAction;
    }

    public void setSortByCountryAction(Action sortByCountryAction) {
        this.sortByCountryAction = sortByCountryAction;
    }

    public void setNewCountryAction(JThequeAction newCountryAction) {
        this.newCountryAction = newCountryAction;
    }

    public void setToolBar(JPanelActorToolBar toolBar) {
        this.toolBar = toolBar;
    }
}