package org.jtheque.films.view.impl.panels;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXPanel;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.persistence.able.DataContainer;
import org.jtheque.core.managers.view.impl.actions.JThequeSimpleAction;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.abstraction.Film;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.view.able.IInfosActorsView;
import org.jtheque.films.view.impl.fb.FilmFormBean;
import org.jtheque.films.view.impl.models.list.DataContainerListModel;
import org.jtheque.films.view.impl.models.list.SimpleModel;
import org.jtheque.core.managers.persistence.able.DataContainerProvider;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.utils.ui.GridBagUtils;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.ListSelectionModel;
import javax.swing.JComponent;
import javax.annotation.PostConstruct;
import javax.annotation.Resource;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Cette classe reprsente le panel prsentant les acteurs du film.
 *
 * @author Baptiste Wicht
 */
public final class JPanelInfosActors extends JXPanel implements IInfosActorsView {
    private static final long serialVersionUID = 447863972139498415L;
    
    private JButton buttonAdd;
    private JButton buttonRemove;
    private JList listActeurs;
    private JList listActeursForFilm;
    
    private DataContainerListModel<ActorImpl> actorsModel;
    private SimpleModel<ActorImpl> actorsForFilmModel;
    
    private JThequeSimpleAction removeAction;
    private JThequeSimpleAction addAction;
    
    @Resource
    private IActorService actorsService;
    
    /**
     * Cette mthode initialise le panel.
     */
    @PostConstruct
    private void build() {
        PanelBuilder builder = new PanelBuilder(this);
        
        actorsModel = new DataContainerListModel<ActorImpl>(actorsService);
        
        listActeurs = builder.addList(actorsModel, null, 
                builder.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.ABOVE_BASELINE_LEADING, 1, 0, 0.5, 1.0));
        listActeurs.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);

        actorsForFilmModel = new SimpleModel<ActorImpl>();
        
        listActeursForFilm = builder.addList(actorsForFilmModel, null, 
                builder.gbcSet(2, 0, GridBagUtils.BOTH, GridBagUtils.ABOVE_BASELINE_LEADING, 0, 0, 0.5, 1.0));
        listActeursForFilm.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        
        buttonAdd = builder.addButton(addAction, builder.gbcSet(1, 0));
        buttonAdd.setEnabled(false);
        
        buttonRemove = builder.addButton(removeAction, builder.gbcSet(1, 1));
        buttonRemove.setEnabled(false);
    }

    @Override
    public void objectChanged(ObjectChangedEvent event) {
        actorsForFilmModel.removeAllElements();
        actorsModel.reload();

        Set<ActorImpl> acteursOfFilm = ((Film) event.getObject()).getActors();

        for (ActorImpl acteur : acteursOfFilm) {
            actorsModel.removeElement(acteur);
            actorsForFilmModel.addElement(acteur);
        }
    }

    @Override
    public void fillFilm(FilmFormBean fb) {
        if (actorsForFilmModel.getSize() != 0) {
            fb.setActors(new HashSet<ActorImpl>(actorsForFilmModel.getObjects()));
        }
    }

    @Override
    public void setEnabled(boolean enabled) {
        buttonAdd.setEnabled(enabled);
        buttonRemove.setEnabled(enabled);

        super.setEnabled(enabled);
    }

    @Override
    public JComponent getImpl() {
        return this;
    }

    @Override
    public DefaultListModel getActorsModel() {
        return actorsModel;
    }

    @Override
    public DefaultListModel getActorsForFilmModel() {
        return actorsForFilmModel;
    }

    @Override
    public int[] getSelectedActorsIndices() {
        return listActeurs.getSelectedIndices();
    }

    @Override
    public int[] getSelectedActorsForFilmIndices() {
        return listActeursForFilm.getSelectedIndices();
    }

    @Override
    public void validate(List<JThequeError> errors) {
    }

    public void setAddAction(JThequeSimpleAction addAction) {
        this.addAction = addAction;
    }

    public void setRemoveAction(JThequeSimpleAction removeAction) {
        this.removeAction = removeAction;
    }
}