package org.jtheque.films.view.impl.panels;

import org.jdesktop.swingx.JXPanel;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.components.panel.FileChooserPanel;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.films.persistence.od.abstraction.Film;
import org.jtheque.core.utils.ui.constraints.ConstraintManager;
import org.jtheque.films.utils.Constants.Properties;
import org.jtheque.films.view.able.IInfosOthersView;
import org.jtheque.films.view.impl.fb.FilmFormBean;
import org.jtheque.primary.view.impl.listeners.CurrentObjectListener;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.utils.ui.GridBagUtils;

import javax.annotation.PostConstruct;
import javax.swing.JComponent;

import java.util.Collection;
import java.util.List;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Panel for the others informations about film.
 *
 * @author Baptiste Wicht
 */
public final class JPanelInfosOthers extends JXPanel implements IInfosOthersView {
    private FileChooserPanel fieldFile;
    
    /**
     * Build the view.
     */
    @PostConstruct
    private void build() {
        PanelBuilder builder = new PanelBuilder(this);
        
        fieldFile = new FileChooserPanel();
        fieldFile.setTextKey(Properties.Film.FILEPATH);

        builder.add(fieldFile, builder.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.ABOVE_BASELINE_LEADING, 0, 0, 1.0, 1.0));
    }

    @Override
    public void objectChanged(ObjectChangedEvent event) {
        Film film = (Film) event.getObject();

        fieldFile.setFilePath(film.getFilePath());
    }

    /**
     * Fill the formbean.
     *
     * @param fb The formbean to fill.
     */
    @Override
    public void fillFilm(FilmFormBean fb) {
        fb.setFilePath(fieldFile.getFilePath());
    }

    @Override
    public void setEnabled(boolean enabled) {
        fieldFile.setEnabled(enabled);

        super.setEnabled(enabled);
    }

    /**
     * Validate the view.
     *
     * @param errors The errors list to fill.
     */
    public void validate(List<JThequeError> errors) {
        ConstraintManager.validate(Properties.Film.FILEPATH, fieldFile.getFilePath(), errors);
    }

    @Override
    public JComponent getImpl() {
        return this;
    }
}