package org.jtheque.films.view.impl.panels;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXHyperlink;
import org.jdesktop.swingx.JXTitledPanel;
import org.jdesktop.swingx.JXTree;
import org.jdesktop.swingx.border.DropShadowBorder;
import org.jtheque.core.managers.error.JThequeError;
import org.jtheque.core.managers.view.impl.actions.JThequeAction;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.utils.ui.Borders;
import org.jtheque.films.controllers.able.IRealizerController;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.core.utils.ui.constraints.ConstraintManager;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.utils.Constants.Properties.Person;
import org.jtheque.films.view.able.IRealizerView;
import org.jtheque.films.view.impl.fb.RealizerFormBean;
import org.jtheque.films.view.impl.models.RealizersModel;
import org.jtheque.films.view.impl.toolbars.JPanelRealizerToolBar;
import org.jtheque.primary.od.CountryImpl;
import org.jtheque.primary.services.able.ICountriesService;
import org.jtheque.primary.view.able.ToolbarView;
import org.jtheque.primary.view.impl.components.panels.JThequeTitledPanel;
import org.jtheque.primary.view.impl.components.panels.PrincipalDataPanel;
import org.jtheque.primary.view.impl.listeners.ObjectChangedEvent;
import org.jtheque.primary.view.impl.models.DataContainerCachedComboBoxModel;
import org.jtheque.primary.view.impl.models.NotesComboBoxModel;
import org.jtheque.primary.view.impl.renderers.JThequeTreeCellRenderer;
import org.jtheque.primary.view.impl.renderers.NoteComboRenderer;
import org.jtheque.primary.view.impl.sort.SortManager;
import org.jtheque.utils.ui.GridBagUtils;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JTextField;
import javax.swing.Action;

import java.awt.Font;
import java.util.List;

/**
 * Cette classe est le panel reprsentant les Ralisateurs.
 *
 * @author Baptiste Wicht
 */
public final class RealizerView extends PrincipalDataPanel implements IRealizerView {
    private static final long serialVersionUID = -4304886748651187432L;

    private JXTitledPanel panelRealisateur;

    private JTextField fieldFirstName;
    private JTextField fieldName;
    private DataContainerCachedComboBoxModel<CountryImpl> modelCountries;
    private NotesComboBoxModel modelNote;
    private JComboBox comboCountries;
    private JComboBox comboNote;
    private JPanelRealizerToolBar toolBar;

    private JXTree treeRealisateurs;

    /* Instances */
    private final SortManager sorter = new SortManager();

    @Resource
    private ICountriesService countriesService;
    
    @Resource
    private IRealizerController realizerController;
    
    private JThequeAction newCountryAction;
    private Action sortByNoteAction;
    private Action sortByCountryAction;

    @Override
    @PostConstruct
    public void build() {
        getModel().addDisplayListListener(this);
        
        PanelBuilder builder = new PanelBuilder(this);

        buildPanelListe(builder);
        buildPanelTri(builder);
        buildPanelRealizer(builder);

        setBorder(Borders.DIALOG_BORDER);

        addListeners();
        
        selectFirst();
    }

    private void addListeners() {
        treeRealisateurs.addTreeSelectionListener(realizerController);

        getModel().addCurrentObjectListener(this);
    }

    /**
     * Build the internal panel realizer.
     * 
     * @param parent The builder of the frame. 
     */
    private void buildPanelRealizer(PanelBuilder parent) {
        panelRealisateur = new JThequeTitledPanel("realizer.view.panel.realizer.title");
        panelRealisateur.setBorder(new DropShadowBorder());
        panelRealisateur.setTitleFont(panelRealisateur.getTitleFont().deriveFont(Font.BOLD));
        
        PanelBuilder builder = new PanelBuilder();
        
        builder.add(toolBar, builder.gbcSet(0, 0, GridBagUtils.HORIZONTAL, 0, 1));
        
        builder.addI18nLabel(Person.FIRSTNAME, builder.gbcSet(0, 1));
        
        fieldFirstName = builder.add(new JTextField(20), builder.gbcSet(1, 1, GridBagUtils.NONE, 0, 1));
        ConstraintManager.configure(fieldFirstName, Person.FIRSTNAME);
        fieldFirstName.setEnabled(false);

        builder.addI18nLabel(Person.NAME, builder.gbcSet(0, 2));
        
        fieldName = builder.add(new JTextField(20), builder.gbcSet(1, 2, GridBagUtils.NONE, 0, 1));
        ConstraintManager.configure(fieldName, Person.NAME);
        fieldName.setEnabled(false);

        builder.addI18nLabel(Person.COUNTRY, builder.gbcSet(0, 3));

        modelCountries = new DataContainerCachedComboBoxModel<CountryImpl>(countriesService);
        
        comboCountries = builder.addComboBox(modelCountries, builder.gbcSet(1, 3));
        comboCountries.setEnabled(false);
        
        newCountryAction.setEnabled(false);

        builder.addButton(newCountryAction, builder.gbcSet(2, 3, GridBagUtils.NONE, 0, 1));

        builder.addI18nLabel(Person.NOTE, builder.gbcSet(0, 4));

        modelNote = new NotesComboBoxModel();
        
        comboNote = builder.addComboBox(modelNote, builder.gbcSet(1, 4, GridBagUtils.NONE, GridBagUtils.ABOVE_BASELINE_LEADING, 0, 0, 1.0, 1.0));
        comboNote.setEnabled(false);
        comboNote.setRenderer(new NoteComboRenderer());

        panelRealisateur.setContentContainer(builder.getPanel());
        
        parent.add(panelRealisateur, parent.gbcSet(1, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 1, 2, 0.75, 1.0));
    }

    /**
     * Build the internal panel sort.
     * 
     * @param parent The builder of the frame. 
     */
    private void buildPanelTri(PanelBuilder parent) {
        JXTitledPanel panelTri = new JThequeTitledPanel("realizer.view.panel.sort.title");
        panelTri.setBorder(new DropShadowBorder());
        panelTri.setTitleFont(panelTri.getTitleFont().deriveFont(Font.BOLD));

        PanelBuilder builder = new PanelBuilder();
        
        JXHyperlink linkTriPays = builder.add(new JXHyperlink(sortByCountryAction), 
                builder.gbcSet(0, 0, GridBagUtils.NONE, GridBagUtils.BASELINE_LEADING, 0, 1, 1.0, 0.0));
        linkTriPays.setClickedColor(linkTriPays.getUnclickedColor());
        
        JXHyperlink linkTriNote = builder.add(new JXHyperlink(sortByNoteAction), 
                builder.gbcSet(0, 1, GridBagUtils.NONE, GridBagUtils.BASELINE_LEADING, 0, 1, 1.0, 0.0));
        linkTriNote.setClickedColor(linkTriNote.getUnclickedColor());

        panelTri.setContentContainer(builder.getPanel());
        
        parent.add(panelTri, parent.gbcSet(0, 1, GridBagUtils.HORIZONTAL, GridBagUtils.FIRST_LINE_START, 0.25, 0.0));
    }

    /**
     * Build the internal panel list.
     * 
     * @param parent The builder of the frame. 
     */
    private void buildPanelListe(PanelBuilder parent) {
        JXTitledPanel panelListe = new JThequeTitledPanel("realizer.view.panel.list.title");
        panelListe.setBorder(new DropShadowBorder());
        panelListe.setTitleFont(panelListe.getTitleFont().deriveFont(Font.BOLD));

        PanelBuilder builder = new PanelBuilder();

        setTreeModel(sorter.createInitialModel(IRealizersService.DATA_TYPE));
        
        treeRealisateurs = new JXTree(getTreeModel());
        treeRealisateurs.setCellRenderer(new JThequeTreeCellRenderer());
        treeRealisateurs.putClientProperty("JTree.lineStyle", "None");

        builder.addScrolled(treeRealisateurs, builder.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 0, 0, 1.0, 1.0));

        panelListe.setContentContainer(builder.getPanel());
        
        parent.add(panelListe, parent.gbcSet(0, 0, GridBagUtils.BOTH, GridBagUtils.BASELINE_LEADING, 0.25, 1.0));
    }

    /**
     * Cette mthode permet d'indiquer que l'on change de ralisateur et donc de mettre  jour les champs.
     *
     * @param current Le ralisateur slectionn
     */
    private void setCurrentRealisateur(RealizerImpl current) {
        //On modifie le titre
        panelRealisateur.setTitle(current.getAffichableText());

        //On remplit les champs
        fieldFirstName.setText(current.getFirstName());
        fieldName.setText(current.getName());
        comboCountries.setSelectedItem(current.getTheCountry().getName());
        comboNote.setSelectedItem(current.getNote());
    }

    @Override
    public RealizerFormBean fillRealizerFormBean() {
        RealizerFormBean fb = new RealizerFormBean();

        //On complte les donnes du film avec les donnes de cette interface
        fb.setName(fieldName.getText());
        fb.setFirstName(fieldFirstName.getText());
        fb.setNote(modelNote.getSelectedNote());
        fb.setCountry(modelCountries.getSelectedData());

        return fb;
    }

    @Override
    public void objectChanged(ObjectChangedEvent event) {
        setCurrentRealisateur((RealizerImpl) event.getObject());
    }

    @Override
    public void setEnabled(boolean enabled) {
        fieldFirstName.setEnabled(enabled);
        fieldName.setEnabled(enabled);
        comboCountries.setEnabled(enabled);
        comboNote.setEnabled(enabled);
        newCountryAction.setEnabled(enabled);
    }

    @Override
    public ToolbarView getToolbarView() {
        return toolBar;
    }

    @Override
    public String getDataType() {
        return IRealizersService.DATA_TYPE;
    }

    @Override
    protected JXTree getTree() {
        return treeRealisateurs;
    }

    @Override
    public JComponent getImpl() {
        return this;
    }

    @Override
    public Integer getPosition() {
        return 3;
    }

    @Override
    public String getTitlekey() {
        return "realizer.data.title";
    }

    @Override
    public RealizersModel getModel() {
        return (RealizersModel) super.getModel();
    }

    @Override
    public void clear() {
    }

    @Override
    protected void validate(List<JThequeError> errors) {
        ConstraintManager.validate(Person.NAME, fieldName.getText(), errors);
        ConstraintManager.validate(Person.FIRSTNAME, fieldFirstName.getText(), errors);
        ConstraintManager.validate(Person.COUNTRY, modelCountries.getSelectedData(), errors);
    }

    @Override
    public JComponent getComponent() {
        return this;
    }

    public void setSortByCountryAction(Action sortByCountryAction) {
        this.sortByCountryAction = sortByCountryAction;
    }

    public void setSortByNoteAction(Action sortByNoteAction) {
        this.sortByNoteAction = sortByNoteAction;
    }

    public void setNewCountryAction(JThequeAction newCountryAction) {
        this.newCountryAction = newCountryAction;
    }

    public void setToolBar(JPanelRealizerToolBar toolBar) {
        this.toolBar = toolBar;
    }
}