package org.jtheque.films.view.impl.panels.search;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.films.persistence.od.ActorImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.services.able.IActorService;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.films.services.impl.utils.search.FilmSearch;
import org.jtheque.films.services.impl.utils.search.Search;
import org.jtheque.films.utils.Constants.Properties.Film;
import org.jtheque.films.view.impl.editors.DurationEditor;
import org.jtheque.films.view.impl.models.spinner.SpinnerDurationModel;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.od.KindImpl;
import org.jtheque.primary.od.TypeImpl;
import org.jtheque.primary.services.able.ILanguagesService;
import org.jtheque.primary.services.able.ITypesService;
import org.jtheque.primary.services.able.IKindsService;
import org.jtheque.primary.view.impl.models.DataContainerCachedComboBoxModel;
import org.jtheque.primary.view.impl.models.NotesComboBoxModel;
import org.jtheque.utils.ui.GridBagUtils;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JCheckBox;
import javax.swing.JSpinner;
import javax.swing.JTextField;

/**
 * A search panel for films.
 *
 * @author Baptiste Wicht
 */
public final class JPanelFilmSearch extends JPanelSearch {
    private static final long serialVersionUID = 7108296888681550453L;

    /* Graphics components */
    private JCheckBox boxGenre;
    private JCheckBox boxActeur;
    private JCheckBox boxType;
    private JCheckBox boxAnnee;
    private JTextField fieldAnneeDe;
    private JTextField fieldAnneeA;
    private JCheckBox boxRealisateur;
    private JCheckBox boxLangue;
    private JCheckBox boxNote;
    private JCheckBox boxDuree;
    private JSpinner fieldDureeDe;
    private JSpinner fieldDureeA;

    private NotesComboBoxModel modelNotes;
    private DataContainerCachedComboBoxModel<KindImpl> modelKinds;
    private DataContainerCachedComboBoxModel<ActorImpl> modelActors;
    private DataContainerCachedComboBoxModel<TypeImpl> modelTypes;
    private DataContainerCachedComboBoxModel<RealizerImpl> modelRealizers;
    private DataContainerCachedComboBoxModel<LanguageImpl> modelLanguages;

    @Resource
    private ITypesService typesService;

    @Resource
    private ILanguagesService languagesService;

    @Resource
    private IRealizersService realizersService;

    @Resource
    private IKindsService kindsService;

    @Resource
    private IActorService actorService;
    
    /**
     * Build the panel.
     */
    @PostConstruct
    private void build() {
        PanelBuilder builder = new PanelBuilder(this);
        
        boxGenre = builder.add(new JCheckBox(), builder.gbcSet(0, 0));

        builder.addI18nLabel(Film.KIND, builder.gbcSet(1, 0));

        modelKinds = new DataContainerCachedComboBoxModel<KindImpl>(kindsService);

        builder.addComboBox(modelKinds, builder.gbcSet(2, 0, GridBagUtils.NONE, 2, 1));
        
        boxActeur = builder.add(new JCheckBox(), builder.gbcSet(0, 1));

        builder.addI18nLabel(Film.ACTORS, builder.gbcSet(1, 1));

        modelActors = new DataContainerCachedComboBoxModel<ActorImpl>(actorService);

        builder.addComboBox(modelActors, builder.gbcSet(2, 1, GridBagUtils.NONE, 2, 1));
        
        boxType = builder.add(new JCheckBox(), builder.gbcSet(0, 2));

        builder.addI18nLabel(Film.TYPE, builder.gbcSet(1, 2));

        modelTypes = new DataContainerCachedComboBoxModel<TypeImpl>(typesService);

        builder.addComboBox(modelTypes, builder.gbcSet(2, 2, GridBagUtils.NONE, 2, 1));
        
        boxAnnee = builder.add(new JCheckBox(), builder.gbcSet(0, 3));

        builder.addI18nLabel(Film.YEAR, builder.gbcSet(1, 3));
        
        fieldAnneeDe = builder.add(new JTextField(4), builder.gbcSet(2, 3));

        builder.addI18nLabel("search.film.to", builder.gbcSet(3, 3));
        
        fieldAnneeA = builder.add(new JTextField(4), builder.gbcSet(4, 3));
        
        boxRealisateur = builder.add(new JCheckBox(), builder.gbcSet(0, 4));

        builder.addI18nLabel(Film.REALIZER, builder.gbcSet(1, 4));

        modelRealizers = new DataContainerCachedComboBoxModel<RealizerImpl>(realizersService);

        builder.addComboBox(modelRealizers, builder.gbcSet(2, 4, GridBagUtils.NONE, 2, 1));
        
        boxLangue = builder.add(new JCheckBox(), builder.gbcSet(0, 5));

        builder.addI18nLabel(Film.LANGUAGE, builder.gbcSet(1, 5));

        modelLanguages = new DataContainerCachedComboBoxModel<LanguageImpl>(languagesService);

        builder.addComboBox(modelLanguages, builder.gbcSet(2, 5, GridBagUtils.NONE, 2, 1));

        boxNote = builder.add(new JCheckBox(), builder.gbcSet(0, 6));

        builder.addI18nLabel(Film.NOTE, builder.gbcSet(1, 6));

        modelNotes = new NotesComboBoxModel();

        builder.addComboBox(modelNotes, builder.gbcSet(2, 6, GridBagUtils.NONE, 2, 1));

        boxDuree = builder.add(new JCheckBox(), builder.gbcSet(0, 7));

        builder.addI18nLabel(Film.DURATION, builder.gbcSet(1, 7));

        fieldDureeDe = new JSpinner(new SpinnerDurationModel("1:00"));
        fieldDureeDe.setEditor(new DurationEditor(fieldDureeDe));
        builder.add(fieldDureeDe, builder.gbcSet(2, 7));

        builder.addI18nLabel("search.film.to", builder.gbcSet(3, 7));

        fieldDureeA = new JSpinner(new SpinnerDurationModel("2:00"));
        fieldDureeA.setEditor(new DurationEditor(fieldDureeA));
        builder.add(fieldDureeA, builder.gbcSet(4, 7));
    }

    @Override
    public String getTitle() {
        return Managers.getManager(ILanguageManager.class).getMessage("search.film.title");
    }

    @Override
    public Search<FilmImpl> getSearch() {
        FilmSearch search = new FilmSearch();

        search.setMustCheckActor(boxActeur.isSelected());
        search.setMustCheckKind(boxGenre.isSelected());
        search.setMustCheckType(boxType.isSelected());
        search.setMustCheckRealizer(boxRealisateur.isSelected());
        search.setMustCheckLanguage(boxLangue.isSelected());
        search.setMustCheckNote(boxNote.isSelected());
        search.setMustCheckYear(boxAnnee.isSelected());
        search.setMustCheckDuration(boxDuree.isSelected());

        search.setActor(modelActors.getSelectedData());
        search.setKind(modelKinds.getSelectedData());
        search.setType(modelTypes.getSelectedData());
        search.setRealizer(modelRealizers.getSelectedData());
        search.setLanguage(modelLanguages.getSelectedData());
        search.setNote(modelNotes.getSelectedNote());

        if (search.isMustCheckYear()) {
            search.setEndYear(Integer.parseInt(fieldAnneeA.getText()));
            search.setStartYear(Integer.parseInt(fieldAnneeDe.getText()));
        }

        search.setEndDuration(((SpinnerDurationModel) fieldDureeA.getModel()).intValue());
        search.setStartDuration(((SpinnerDurationModel) fieldDureeDe.getModel()).intValue());

        return search;
    }
}