package org.jtheque.films.view.impl.sort;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.films.persistence.od.RealizerImpl;
import org.jtheque.films.persistence.od.FilmImpl;
import org.jtheque.films.services.able.IRealizersService;
import org.jtheque.films.controllers.able.IFilmController;
import org.jtheque.primary.view.impl.models.tree.Category;
import org.jtheque.primary.view.impl.models.tree.JThequeTreeModel;
import org.jtheque.primary.view.impl.models.tree.RootElement;
import org.jtheque.primary.view.impl.sort.Sorter;

import javax.annotation.Resource;

import java.util.List;

/**
 * Cette classe permet de raliser un tri par ralisateur.
 *
 * @author Baptiste Wicht
 */
public final class ByRealizerSorter implements Sorter {
    @Resource
    private IRealizersService realizersService;
    
    @Resource
    private IFilmController filmController;

    @Override
    public boolean canSort(final String content, final String sortType) {
        return content.equals(filmController.getDataType()) && sortType.equals(IRealizersService.DATA_TYPE);
    }

    @Override
    public void sort(JThequeTreeModel model) {
        RootElement root = model.getRoot();

        List<RealizerImpl> groups = realizersService.getRealizers();

        for (RealizerImpl realizer : groups) {
            root.addCategory(new Category(realizer.getElementName()));
        }

        for (FilmImpl film : filmController.getDisplayList()) {
            int index = groups.indexOf(film.getTheRealizer());

            root.getCategory(index).addElement(film);
        }

        model.setRootElement(root);
    }
}